What is pysoundanalyser? — pysoundanalyser 0.3.7 documentation

# What is `pysoundanalyser`?

`pysoundanalyser` is an application which provides a graphical user interface to analyse short (in the range of seconds) wav files. I developed and use it mainly to quickly load and visualize the waveforms and the spectral content of sounds generated for psychoacoustics research. `pysoundanalyser` can also generate some types of sounds used in psychoacoustics research (e.g. pure tones, amplitude modulated tones, frequency modulated tones, different colors of noise, etc…).

The repository of `pysoundanalyser` is hosted on GitHub. If you find bugs, please report them there.